### organism specific functions for HiCdat
### automatically generated by HiCdat-map

#'@title Definition of the chromosome sizes. 
#'@return a list with chromosome sizes.
#'@note this default is for A. thaliana, TAIR10. To use another assembly, create a new source file
#'using the HiCdatPre binary (\url{https://github.com/MWSchmid/HiCdat}) and load it after loading the HiCdatR package
#'with \code{source("myOrganismSpecificCode.R")}.
#'@author Marc W. Schmid \email{marcschmid@@gmx.ch} and Stefan Grob \email{stefan@@grob.org}.
f.get.chrom.sizes <- function() {
	out <- list(
		'Chr1' = 30427671,
		'Chr2' = 19698289,
		'Chr3' = 23459830,
		'Chr4' = 18585056,
		'Chr5' = 26975502,
		'ChrC' = 154478,
		'ChrM' = 366924)
	return(out)
}

#'@title Restriction fragment indices of the chromosomes. 
#'@return a list containing the start and end restriction fragments for each chromosome.
#'@note this default is for A. thaliana, TAIR10, digested with HindIII. To use another assembly or restriction enzyme,
#'create a new source file using the HiCdatPre binary (\url{https://github.com/MWSchmid/HiCdat}) and load it after loading the HiCdatR package
#'with \code{source("myOrganismSpecificCode.R")}.
#'@author Marc W. Schmid \email{marcschmid@@gmx.ch} and Stefan Grob \email{stefan@@grob.org}.
f.get.frag.list <- function() {
	out <- list(
		'Chr1' = c(1, 16964),
		'Chr2' = c(16965, 27440),
		'Chr3' = c(27441, 40011),
		'Chr4' = c(40012, 51069),
		'Chr5' = c(51070, 66846),
		'ChrC' = c(66847, 66893),
		'ChrM' = c(66894, 67064))
	return(out)
}

#'@title Definition of chromosomes of interest.
#'@return a vector containing the chromosome names of interest.
#'@note this default is for A. thaliana, TAIR10. To use another assembly, create a new source file
#'using the HiCdatPre binary (\url{https://github.com/MWSchmid/HiCdat}) and load it after loading the HiCdatR package
#'with \code{source("myOrganismSpecificCode.R")}.
#'@author Marc W. Schmid \email{marcschmid@@gmx.ch} and Stefan Grob \email{stefan@@grob.org}.
f.get.relevant.chromosomes <- function() {
	out <- c('Chr1', 'Chr2', 'Chr3', 'Chr4', 'Chr5')
	return(out)
}
